@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: optparse-simple
 version: 0.0.3
-id: optparse-simple-0.0.3-d3805f1b9bb6c526e5e3f8d9770635c2
-key: optpa_2q4Do3ILX3M7MahNWD8OlJ
+id: optparse-simple-0.0.3-be3ce0f531703a193d1ed150a818e98b
+key: optpa_IZDqcMThK510kEXQK11tBD
 license: BSD3
 copyright: 2015 FP Complete
 maintainer: chrisdone@fpcomplete.com
@@ -19,10 +19,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/optparse-simple-0.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/optparse-simple-0.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/optparse-simple-0.0.3
-hs-libraries: HSoptparse-simple-0.0.3-2q4Do3ILX3M7MahNWD8OlJ
+hs-libraries: HSoptparse-simple-0.0.3-IZDqcMThK510kEXQK11tBD
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    either-4.4.1-02b52c35841743771b37e0d5948e3cc8
+    either-4.4.1-034f73c037cf6acbd6a0e4686245d294
     gitrev-1.2.0-e94a60465b66be18f7d5d663af7880a5
     optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
